@@ -36,7 +36,7 @@ extern void init_debug (void);
 extern int debug_level;
 extern void debug (const char *message, ...) PIPELINE_ATTR_FORMAT_PRINTF(1, 2);
 
-#ifndef HAVE_CLEARENV
+#if defined(HAVE_SETENV) && !defined(HAVE_CLEARENV)
 extern int clearenv (void);
 #endif
 
